pytilities.geometry.vector — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.vector

class `pytilities.geometry.vector.` `Vector`(*args, **kwargs)

  2D Point/Vector with coordinates in a continuous space (float).

  Note on Vector, DiscreteVector operations: Vector op DiscreteVector returns Vector. DiscreteVector op DiscreteVector returns DiscreteVector.

  `__abs__`(*args, **kwargs)
  `__delattr__`(*args, **kwargs)
  `__getattribute__`(*args, **kwargs)
  `__init__`(*args, **kwargs)
  `__itruediv__`(*args, **kwargs)
  `__rtruediv__`(*args, **kwargs)
  `__setattr__`(*args, **kwargs)
  `__truediv__`(*args, **kwargs)
  `cross`(*args, **kwargs)
  `dot`(*args, **kwargs)
  `normalize`(*args, **kwargs)
  `normalized`(*args, **kwargs)
  `reflect`(*args, **kwargs)
  `length`

    Read-write, length of vector

    Returns :: float | int

    Set parameters:

    > value :: number
    >   new length

  `length_squared`

    Read-only, length squared :: float | int

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »